import { UserNullableType, StateType, IdType } from '../../types';
/**
 * Emits data back to the user via socket or collects it internally under task.results. Emit is queued.
 *
 * @param {IdType} user
 * @param {Object | Array<Object>} data
 * @param {IdType} task
 * @param {IdType | void} worker
 * @param {boolean = false} wrap - Wrap the message into Begin- & EndFrame pairs
 */
export declare function emit(user: IdType, data: any | Array<any>, task: IdType, worker: IdType | void, wrap?: boolean): (dispatch: any, getState: () => StateType) => any;
/**
 * Emits Begin- & End-framed data back to the user via socket or collects it internally under task.results. Emit is queued.
 *
 * @param {IdType} user
 * @param {Object | Array<Object>} data
 * @param {IdType} task
 * @param {IdType | void} worker
 */
export declare function emitFrame(user: IdType, data: Object | Array<Object>, task: IdType, worker: IdType | void): (dispatch: any, getState: () => StateType) => any;
/**
 * Adds new user
 *
 * @param {IdType} user
 * @param {*} socket
 */
export declare function addUser(user: IdType, socket?: any): (dispatch: any, getState: () => StateType) => void;
/**
 * Removes existing user
 *
 * @param {IdType} user
 */
export declare function removeUser(user: IdType): (dispatch: any, getState: () => StateType) => void;
/**
 * Updates existing user
 *
 * @param {IdType} user
 * @param {UserNullableType} updates
 */
export declare function updateUser(user: IdType, updates?: UserNullableType): {
    type: string;
    user: string;
    updates: UserNullableType | undefined;
};
/**
 * Stores user state in its local state-folder
 *
 * @param {IdType} user
 * @param {IdType} worker
 */
export declare function storeState(user: IdType, worker?: IdType, task?: IdType): (dispatch: any, getState: () => StateType) => Promise<any>;
/**
 * loads the most recent user state from its local user state-folder.
 *
 * @param {IdType} user
 * @param {IdType} worker
 */
export declare function loadState(user: IdType, worker?: IdType, task?: IdType, name?: string): (dispatch: any, getState: () => StateType) => Promise<any>;
/**
 * Clear all states.
 *
 * @param {IdType} user
 */
export declare function clearStates(user: IdType): (dispatch: any, getState: () => StateType) => Promise<void>;
/**
 * Either call loadState or cause a simple ping in order to prevent choking
 * the client which might be waiting for a response.
 *
 * @param {IdType} user
 * @param {'undo' | 'redo'} type
 */
export declare function undoRedo(user: IdType, type: 'undo' | 'redo', task?: IdType): (dispatch: any, getState: () => StateType) => Promise<void>;
/**
 * Deals with a users socket and dispatches actions
 *
 * @param {*} socket
 */
export declare function handleUser(socket: any): (dispatch: any, getState: () => StateType) => Promise<void>;
